@@ -3,11 +3,15 @@
 import os
 from typing import Optional, Tuple
 
+import ndebug
 import requests
 
 from .errors import ImproperConfigurationError
 from .settings import config
 
+debug = ndebug.create(__name__)
+debug_gh = ndebug.create(__name__ + ':github')
+
 
 class Base(object):
 
@@ -52,6 +56,8 @@ class Github(Base):
         response = requests.get(
             url.format(domain=Github.DOMAIN, owner=owner, repo=repo, ref=ref)
         )
+        if debug_gh.enabled:
+            debug_gh('check_build_status: state={}'.format(response.json()['state']))
         return response.json()['state'] == 'success'
 
     @classmethod
@@ -68,6 +74,7 @@ class Github(Base):
         """
         url = '{domain}/repos/{owner}/{repo}/releases?access_token={token}'
         tag = 'v{0}'.format(version)
+        debug_gh('listing releases')
         response = requests.post(
             url.format(
                 domain=Github.DOMAIN,
@@ -78,8 +85,10 @@ class Github(Base):
             json={'tag_name': tag, 'body': changelog, 'draft': False, 'prerelease': False}
         )
         status, payload = response.status_code == 201, response.json()
+        debug_gh('response #1, status_code={}, status={}'.format(response.status_code, status))
 
         if not status:
+            debug_gh('not status, getting tag', tag)
             url = '{domain}/repos/{owner}/{repo}/releases/tags/{tag}?access_token={token}'
             response = requests.get(
                 url.format(
@@ -91,7 +100,9 @@ class Github(Base):
                 ),
             )
             release_id = response.json()['id']
+            debug_gh('response #2, status_code={}'.format(response.status_code))
             url = '{domain}/repos/{owner}/{repo}/releases/{id}?access_token={token}'
+            debug_gh('getting release_id', release_id)
             response = requests.post(
                 url.format(
                     domain=Github.DOMAIN,
@@ -103,6 +114,7 @@ class Github(Base):
                 json={'tag_name': tag, 'body': changelog, 'draft': False, 'prerelease': False}
             )
             status, payload = response.status_code == 200, response.json()
+            debug_gh('response #3, status_code={}, status={}'.format(response.status_code, status))
         return status, payload
 
 
@@ -112,6 +124,7 @@ def get_hvcs() -> Base:
     :raises ImproperConfigurationError: if the hvcs option provided is not valid
     """
     hvcs = config.get('semantic_release', 'hvcs')
+    debug('get_hvcs: hvcs=', hvcs)
     try:
         return globals()[hvcs.capitalize()]
     except KeyError:
@@ -127,6 +140,7 @@ def check_build_status(owner: str, repository: str, ref: str) -> bool:
     :param ref: Commit or branch reference
     :return: A boolean with the build status
     """
+    debug('check_build_status')
     return get_hvcs().check_build_status(owner, repository, ref)
 
 
@@ -140,6 +154,7 @@ def post_changelog(owner: str, repository: str, version: str, changelog: str) ->
     :param changelog: A string with the changelog in correct format
     :return: a tuple with success status and payload from hvcs
     """
+    debug('post_changelog(owner={}, repository={}, version={})'.format(owner, repository, version))
     return get_hvcs().post_release_changelog(owner, repository, version, changelog)
 
 
