@@ -134,13 +134,19 @@ def tag_new_version(version: str):
     return repo.git.tag('-a', 'v{0}'.format(version), m='v{0}'.format(version))
 
 
-def push_new_version(gh_token: str = None, owner: str = None, name: str = None):
+def push_new_version(
+    gh_token: str = None,
+    owner: str = None,
+    name: str = None,
+    branch: str = "master"
+):
     """
     Runs git push and git push --tags.
 
     :param gh_token: Github token used to push.
     :param owner: Organisation or user that owns the repository.
     :param name: Name of repository.
+    :param branch: Branch to push to
     :raises GitError: if GitCommandError is raised
     """
 
@@ -153,8 +159,8 @@ def push_new_version(gh_token: str = None, owner: str = None, name: str = None):
         )
 
     try:
-        repo.git.push(server, 'master')
-        repo.git.push('--tags', server, 'master')
+        repo.git.push(server, branch)
+        repo.git.push('--tags', server, branch)
     except GitCommandError as error:
         message = str(error)
         if gh_token:
